@@ -6,6 +6,7 @@
 ## estimating high-dimensional integrals by quasi-Monte Carlo methods"),
 ## Mathematics and Computers in Simulation, 62 (3--6), 255--263
 
+require(simsalapar)
 require(qrng)
 require(copula)
 
@@ -34,8 +35,8 @@ rAC_MO <- function(u, family, theta)
                 },
                 "Gumbel" = {
                     ## takes long...
-                    stabledist::qstable(u[,1], alpha=1/theta, beta=1, gamma=cos(pi/(2*theta))^theta,
-                                        delta=theta==1, pm=1)
+                    qstable(u[,1], alpha=1/theta, beta=1, gamma=cos(pi/(2*theta))^theta,
+                            delta=theta==1, pm=1)
                 },
                 stop("'family' not implemented"))
     E <- qexp(u[,-1]) # (n, d)-matrix of Exp(1)
